@@ -12,16 +12,18 @@ def programming_joke():
     response = requests.request("GET", url)
     print(response.text)
 
-#not complete yet
-#def chuck_norris_joke():
-#    url = "https://matchilling-chuck-norris-jokes-v1.p.rapidapi.com/jokes/random"
-#    headers = {
-#	    "accept": "application/json",
-#	    "X-RapidAPI-Key": "2438e24119mshcb8c5b0532b594fp12cd6cjsna4090ec4d7dc",
-#	    "X-RapidAPI-Host": "matchilling-chuck-norris-jokes-v1.p.rapidapi.com"
-#   }
-#    response = requests.request("GET", url, headers=headers)
-#    print(response.text)
+'''
+Not done yet
+def chuck_norris_joke():
+    url = "https://matchilling-chuck-norris-jokes-v1.p.rapidapi.com/jokes/random"
+    headers = {
+	    "accept": "application/json",
+	    "X-RapidAPI-Key": "blank",
+	    "X-RapidAPI-Host": "matchilling-chuck-norris-jokes-v1.p.rapidapi.com"
+   }
+    response = requests.request("GET", url, headers=headers)
+    print(response.text)
+'''
 
 def random_joke():
     url = "https://v2.jokeapi.dev/joke/Any?blacklistFlags=nsfw,religious,political,racist,sexist,explicit&format=txt"
@@ -29,7 +31,7 @@ def random_joke():
     print(response.text)
 
 def JOD():
-    print("https://v2.jokeapi.dev/joke/Any?blacklistFlags=nsfw,religious,political,racist,sexist,explicit&format=txt")
+    print("What did the gun say when it fell down. Shoot!")
 
 def Multiple_Jokes(n):
     for i in range(n):
@@ -38,5 +40,11 @@ def Multiple_Jokes(n):
         soup = BeautifulSoup(html_content, "html.parser")
         print(soup.find('p').text)
 
+def sjoke(Joke_id):
+    url = f"https://icanhazdadjoke.com/j/{Joke_id}"
+    html_content = requests.get(url).text
+    soup = BeautifulSoup(html_content, "html.parser")
+    print(soup.find('p').text)
+
 def version():
-    print("0.0.3")
\ No newline at end of file
+    print("0.0.4")
